[nautilus-actions/file-manager-actions] NAIImporter interface is renamed to FMAIImporter



commit fd815147537f9b63208524fa1b5699ad8713fa69
Author: Pierre Wieser <pwieser trychlos org>
Date:   Mon Sep 7 22:45:26 2015 +0200

    NAIImporter interface is renamed to FMAIImporter

 src/api/Makefile.am                          |    2 +-
 src/api/fma-extension.h                      |    2 +-
 src/api/fma-iexporter.h                      |    2 +-
 src/api/{na-iimporter.h => fma-iimporter.h}  |  156 +++++++++++++-------------
 src/core/Makefile.am                         |    2 +-
 src/core/{na-iimporter.c => fma-iimporter.c} |   66 ++++++------
 src/core/na-importer-ask.c                   |    4 +-
 src/core/na-importer.c                       |   22 ++--
 src/core/na-importer.h                       |   14 +-
 src/core/na-pivot.h                          |    2 +-
 src/io-desktop/nadp-desktop-provider.c       |   10 +-
 src/io-desktop/nadp-reader.c                 |   14 +-
 src/io-desktop/nadp-reader.h                 |    4 +-
 src/io-xml/naxml-provider.c                  |   12 +-
 src/io-xml/naxml-reader.c                    |   20 ++--
 src/io-xml/naxml-reader.h                    |    4 +-
 src/nact/nact-preferences-editor.c           |    2 +-
 17 files changed, 169 insertions(+), 169 deletions(-)
---
diff --git a/src/api/Makefile.am b/src/api/Makefile.am
index 5c71ea6..4613cf5 100644
--- a/src/api/Makefile.am
+++ b/src/api/Makefile.am
@@ -32,7 +32,7 @@ api_include_HEADERS = \
        \
        fma-dbus.h                                                                                      \
        fma-iexporter.h                                                                         \
-       na-iimporter.h                                                                          \
+       fma-iimporter.h                                                                         \
        fma-ifactory-provider.h                                                         \
        fma-ifactory-provider-provider.h                                                \
        na-iio-provider.h                                                                       \
diff --git a/src/api/fma-extension.h b/src/api/fma-extension.h
index 7ceacb3..49c2d5b 100644
--- a/src/api/fma-extension.h
+++ b/src/api/fma-extension.h
@@ -75,7 +75,7 @@
  *        </title>
  *        <para>
  *          This extension is provided via the public
- *          <link linkend="NAIImporter">NAIImporter</link>
+ *          <link linkend="FMAIImporter">FMAIImporter</link>
  *          interface; it takes care of importing menus and actions
  *          from the filesystem into the &prodname; Configuration Tool
  *          user interface.
diff --git a/src/api/fma-iexporter.h b/src/api/fma-iexporter.h
index e199c53..9d214ae 100644
--- a/src/api/fma-iexporter.h
+++ b/src/api/fma-iexporter.h
@@ -408,7 +408,7 @@ typedef struct {
         *
         * If this method is not implemented by the plugin,
         * FileManager-Actions considers that the plugin only implements
-        * the version 1 of the NAIImporter interface.
+        * the version 1 of the FMAIImporter interface.
         *
         * Return value: if implemented, this method must return the version
         * number of this interface the I/O provider is supporting.
diff --git a/src/api/na-iimporter.h b/src/api/fma-iimporter.h
similarity index 73%
rename from src/api/na-iimporter.h
rename to src/api/fma-iimporter.h
index 801f288..faa2d45 100644
--- a/src/api/na-iimporter.h
+++ b/src/api/fma-iimporter.h
@@ -27,20 +27,20 @@
  *   ... and many others (see AUTHORS)
  */
 
-#ifndef __FILE_MANAGER_ACTIONS_API_NA_IIMPORTER_H__
-#define __FILE_MANAGER_ACTIONS_API_NA_IIMPORTER_H__
+#ifndef __FILE_MANAGER_ACTIONS_API_IIMPORTER_H__
+#define __FILE_MANAGER_ACTIONS_API_IIMPORTER_H__
 
 /**
  * SECTION: iimporter
- * @title: NAIImporter
+ * @title: FMAIImporter
  * @short_description: The Import Interface
- * @include: file-manager-actions/na-iimporter.h
+ * @include: file-manager-actions/fma-iimporter.h
  *
- * The #NAIImporter interface imports items from the outside world
+ * The #FMAIImporter interface imports items from the outside world
  * into &prodname; repository (see #NAIIOProvider interface for how
  * these items will be later managed to be store somewhere).
  *
- * In version 1 of the #NAIImporter interface, &prodname; used to
+ * In version 1 of the #FMAIImporter interface, &prodname; used to
  * provide the implementation with all was needed to be able to manage
  * the import process up to be ready for insertion, including the
  * deduplication if required.
@@ -53,18 +53,18 @@
  * Starting with &prodname; version 3.2, this interface is bumped to
  * a version 2 which greatly simplifies it.
  *
- * The I/O provider which implements the #NAIImporter interface is no
+ * The I/O provider which implements the #FMAIImporter interface is no
  * more required to check for existence of the imported items, but this
  * check is pushed back to the caller responsability.
  *
  * Rationale is that only the caller is able to check against a valid
- * repository in its current import context, while the #NAIImporter
+ * repository in its current import context, while the #FMAIImporter
  * provider should only be responsible to import an item in memory.
  *
  * <refsect2>
  *  <title>Versions historic</title>
  *  <table>
- *    <title>Historic of the versions of the #NAIImporter interface</title>
+ *    <title>Historic of the versions of the #FMAIImporter interface</title>
  *    <tgroup rowsep="1" colsep="1" align="center" cols="3">
  *      <colspec colname="na-version" />
  *      <colspec colname="api-version" />
@@ -73,7 +73,7 @@
  *      <thead>
  *        <row>
  *          <entry>&prodname; version</entry>
- *          <entry>#NAIImporter interface version</entry>
+ *          <entry>#FMAIImporter interface version</entry>
  *          <entry></entry>
  *          <entry></entry>
  *        </row>
@@ -101,38 +101,38 @@
 
 G_BEGIN_DECLS
 
-#define NA_TYPE_IIMPORTER                      ( na_iimporter_get_type())
-#define NA_IIMPORTER( instance )               ( G_TYPE_CHECK_INSTANCE_CAST( instance, NA_TYPE_IIMPORTER, 
NAIImporter ))
-#define NA_IS_IIMPORTER( instance )            ( G_TYPE_CHECK_INSTANCE_TYPE( instance, NA_TYPE_IIMPORTER ))
-#define NA_IIMPORTER_GET_INTERFACE( instance ) ( G_TYPE_INSTANCE_GET_INTERFACE(( instance ), 
NA_TYPE_IIMPORTER, NAIImporterInterface ))
+#define FMA_TYPE_IIMPORTER                      ( fma_iimporter_get_type())
+#define FMA_IIMPORTER( instance )               ( G_TYPE_CHECK_INSTANCE_CAST( instance, FMA_TYPE_IIMPORTER, 
FMAIImporter ))
+#define FMA_IS_IIMPORTER( instance )            ( G_TYPE_CHECK_INSTANCE_TYPE( instance, FMA_TYPE_IIMPORTER ))
+#define FMA_IIMPORTER_GET_INTERFACE( instance ) ( G_TYPE_INSTANCE_GET_INTERFACE(( instance ), 
FMA_TYPE_IIMPORTER, FMAIImporterInterface ))
 
-typedef struct _NAIImporter                    NAIImporter;
-typedef struct _NAIImporterInterfacePrivate    NAIImporterInterfacePrivate;
+typedef struct _FMAIImporter                    FMAIImporter;
+typedef struct _FMAIImporterInterfacePrivate    FMAIImporterInterfacePrivate;
 
 /**
- * NAIImporterInterface:
+ * FMAIImporterInterface:
  * @get_version:     [should] returns the version of this interface that the
  *                            plugin implements.
  * @import_from_uri: [should] imports an item.
  *
- * This defines the interface that a #NAIImporter should implement.
+ * This defines the interface that a #FMAIImporter should implement.
  */
 typedef struct {
        /*< private >*/
-       GTypeInterface               parent;
-       NAIImporterInterfacePrivate *private;
+       GTypeInterface                parent;
+       FMAIImporterInterfacePrivate *private;
 
        /*< public >*/
        /**
         * get_version:
-        * @instance: the NAIImporter provider.
+        * @instance: the FMAIImporter provider.
         *
         * FileManager-Actions calls this method each time it needs to know
         * which version of this interface the plugin implements.
         *
         * If this method is not implemented by the plugin,
         * FileManager-Actions considers that the plugin only implements
-        * the version 1 of the NAIImporter interface.
+        * the version 1 of the FMAIImporter interface.
         *
         * Return value: if implemented, this method must return the version
         * number of this interface the I/O provider is supporting.
@@ -141,44 +141,44 @@ typedef struct {
         *
         * Since: 2.30
         */
-       guint ( *get_version )    ( const NAIImporter *instance );
+       guint ( *get_version )    ( const FMAIImporter *instance );
 
        /**
         * import_from_uri:
-        * @instance: the NAIImporter provider.
-        * @parms: a NAIImporterImportFromUriParms structure.
+        * @instance: the FMAIImporter provider.
+        * @parms: a FMAIImporterImportFromUriParms structure.
         *
         * Imports an item.
         *
         * If the provider implements the version 1 of this interface, then
-        * @parms is supposed to map to NAIImporterImportFromUriParms structure.
+        * @parms is supposed to map to FMAIImporterImportFromUriParms structure.
         *
         * Contrarily, if the provider implements the version 2 of the interface,
-        * then @parms is supposed to map to a NAIImporterImportFromUriParmsv2
+        * then @parms is supposed to map to a FMAIImporterImportFromUriParmsv2
         * structure.
         *
         * Return value: the return code of the operation.
         *
         * Since: 2.30
         */
-       guint ( *import_from_uri )( const NAIImporter *instance, void *parms );
+       guint ( *import_from_uri )( const FMAIImporter *instance, void *parms );
 }
-       NAIImporterInterface;
+       FMAIImporterInterface;
 
 #ifdef NA_ENABLE_DEPRECATED
 /**
- * NAIImporterCheckFn:
+ * FMAIImporterCheckFn:
  * @imported: the currently imported #NAObjectItem -derived object.
  * @fn_data: some data to be passed to the function.
  *
  * In version 1 of the interface, this function may be provided by
- * the caller in order the #NAIImporter provider be able to check for
+ * the caller in order the #FMAIImporter provider be able to check for
  * pre-existence of the imported item.
  * This function should return the already existing item which has the
  * same id than the currently being imported one, or %NULL if the
  * imported id will be unique.
  *
- * If this function is not provided, then the #NAIImporter provider will not
+ * If this function is not provided, then the #FMAIImporter provider will not
  * be able to check for duplicates. In this case, the id of the imported item
  * should be systematically regenerated as a unique id, regardless of the
  * asked import mode.
@@ -205,19 +205,19 @@ typedef struct {
  * Since: 2.30
  * Deprecated: 3.2
  */
-typedef NAObjectItem * ( *NAIImporterCheckFn )( const NAObjectItem *, void * );
+typedef NAObjectItem * ( *FMAIImporterCheckFn )( const NAObjectItem *, void * );
 
 /**
- * NAIImporterAskUserFn:
+ * FMAIImporterAskUserFn:
  * @imported: the currently imported #NAObjectItem.
  * @existing: an already existing #NAObjectItem with same id.
  * @fn_data: some data to be passed to the function.
  *
  * In version 1 of the interface, this function may be provided by the
- * caller as a convenience way for the #NAIImporter to ask the user to
+ * caller as a convenience way for the #FMAIImporter to ask the user to
  * know what to do in the case of a duplicate id.
  *
- * If this function is not provided, and the #NAIImporter does not have
+ * If this function is not provided, and the #FMAIImporter does not have
  * any other way to ask the user, then a 'no import' policy should be
  * preferred when managing duplicate identifiers.
  *
@@ -227,21 +227,21 @@ typedef NAObjectItem * ( *NAIImporterCheckFn )( const NAObjectItem *, void * );
  * Since: 2.30
  * Deprecated: 3.2
  */
-typedef guint ( *NAIImporterAskUserFn )( const NAObjectItem *, const NAObjectItem *, void * );
+typedef guint ( *FMAIImporterAskUserFn )( const NAObjectItem *, const NAObjectItem *, void * );
 
 /**
- * NAIImporterManageImportModeParms:
+ * FMAIImporterManageImportModeParms:
  * @version:       [in] the version of the structure content, equals to 1;
  *                      since structure version 1.
  * @imported:      [in] the imported #NAObjectItem -derived object;
  *                      since structure version 1.
  * @asked_mode:    [in] asked import mode;
  *                      since structure version 1.
- * @check_fn:      [in] a #NAIImporterCheckFn function to check the existence of the imported id;
+ * @check_fn:      [in] a #FMAIImporterCheckFn function to check the existence of the imported id;
  *                      since structure version 1.
  * @check_fn_data: [in] @check_fn data;
  *                      since structure version 1.
- * @ask_fn:        [in] a #NAIImporterAskUserFn function to ask the user what to do in case of a duplicate 
id;
+ * @ask_fn:        [in] a #FMAIImporterAskUserFn function to ask the user what to do in case of a duplicate 
id;
  *                      since structure version 1.
  * @ask_fn_data:   [in] @ask_fn data;
  *                      since structure version 1.
@@ -260,21 +260,21 @@ typedef guint ( *NAIImporterAskUserFn )( const NAObjectItem *, const NAObjectIte
  * Deprecated: 3.2
  */
 typedef struct {
-       guint                version;
+       guint                 version;
        NAObjectItem        *imported;
-       guint                asked_mode;
-       NAIImporterCheckFn   check_fn;
-       void                *check_fn_data;
-       NAIImporterAskUserFn ask_fn;
-       void                *ask_fn_data;
-       gboolean             exist;
-       guint                import_mode;
-       GSList              *messages;
+       guint                 asked_mode;
+       FMAIImporterCheckFn   check_fn;
+       void                 *check_fn_data;
+       FMAIImporterAskUserFn ask_fn;
+       void                 *ask_fn_data;
+       gboolean              exist;
+       guint                 import_mode;
+       GSList               *messages;
 }
-       NAIImporterManageImportModeParms;
+       FMAIImporterManageImportModeParms;
 
 /**
- * NAIImporterImportMode:
+ * FMAIImporterImportMode:
  * @IMPORTER_MODE_NO_IMPORT: a "do not import" mode.
  * @IMPORTER_MODE_RENUMBER:  reallocate a new id when the imported one already exists.
  * @IMPORTER_MODE_OVERRIDE:  override the existing id with the imported one.
@@ -290,12 +290,12 @@ typedef enum {
        IMPORTER_MODE_OVERRIDE,
        IMPORTER_MODE_ASK
 }
-       NAIImporterImportMode;
+       FMAIImporterImportMode;
 
-guint na_iimporter_manage_import_mode( NAIImporterManageImportModeParms *parms );
+guint fma_iimporter_manage_import_mode( FMAIImporterManageImportModeParms *parms );
 
 /**
- * NAIImporterImportFromUriParms:
+ * FMAIImporterImportFromUriParms:
  * @version:       [in] the version of this structure;
  *                      since structure version 1.
  * @uri:           [in] uri of the file to be imported;
@@ -308,12 +308,12 @@ guint na_iimporter_manage_import_mode( NAIImporterManageImportModeParms *parms )
  *                      since structure version 1.
  * @imported:      [out] the imported #NAObjectItem -derived object, or %NULL;
  *                      since structure version 1.
- * @check_fn:      [in] a NAIImporterCheckFn() function to check the existence
+ * @check_fn:      [in] a FMAIImporterCheckFn() function to check the existence
  *                      of the imported id;
  *                      since structure version 1.
  * @check_fn_data: [in] @check_fn data;
  *                      since structure version 1.
- * @ask_fn:        [in] a NAIImporterAskUserFn() function to ask the user what to
+ * @ask_fn:        [in] a FMAIImporterAskUserFn() function to ask the user what to
  *                      do in case of a duplicate id;
  *                      since structure version 1.
  * @ask_fn_data:   [in] @ask_fn data;
@@ -330,24 +330,24 @@ guint na_iimporter_manage_import_mode( NAIImporterManageImportModeParms *parms )
  * Deprecated: 3.2
  */
 typedef struct {
-       guint                version;
-       gchar               *uri;
-       guint                asked_mode;
-       gboolean             exist;
-       guint                import_mode;
+       guint                 version;
+       gchar                *uri;
+       guint                 asked_mode;
+       gboolean              exist;
+       guint                 import_mode;
        NAObjectItem        *imported;
-       NAIImporterCheckFn   check_fn;
-       void                *check_fn_data;
-       NAIImporterAskUserFn ask_fn;
-       void                *ask_fn_data;
-       GSList              *messages;
+       FMAIImporterCheckFn   check_fn;
+       void                 *check_fn_data;
+       FMAIImporterAskUserFn ask_fn;
+       void                 *ask_fn_data;
+       GSList               *messages;
 }
-       NAIImporterImportFromUriParms;
+       FMAIImporterImportFromUriParms;
 
 #endif /* NA_ENABLE_DEPRECATED */
 
 /**
- * NAIImporterImportStatus:
+ * FMAIImporterImportStatus:
  * @IMPORTER_CODE_OK:                import ok.
  * @IMPORTER_CODE_PROGRAM_ERROR:     a program error has been detected.
  *                                   You should open a bug in
@@ -374,10 +374,10 @@ typedef enum {
        IMPORTER_CODE_CANCELLED,
        IMPORTER_CODE_NOT_LOADABLE
 }
-       NAIImporterImportStatus;
+       FMAIImporterImportStatus;
 
 /**
- * NAIImporterImportFromUriParmsv2:
+ * FMAIImporterImportFromUriParmsv2:
  * @version:       [in] the version of the structure, equals to 2;
  *                      since structure version 1.
  * @content:       [in] the version of the description content, equals to 1;
@@ -397,18 +397,18 @@ typedef enum {
  * Since: 3.2
  */
 typedef struct {
-       guint         version;
-       guint         content;
-       const gchar  *uri;
+       guint          version;
+       guint          content;
+       const gchar   *uri;
        NAObjectItem *imported;
-       GSList       *messages;
+       GSList        *messages;
 }
-       NAIImporterImportFromUriParmsv2;
+       FMAIImporterImportFromUriParmsv2;
 
-GType na_iimporter_get_type       ( void );
+GType fma_iimporter_get_type       ( void );
 
-guint na_iimporter_import_from_uri( const NAIImporter *importer, NAIImporterImportFromUriParmsv2 *parms );
+guint fma_iimporter_import_from_uri( const FMAIImporter *importer, FMAIImporterImportFromUriParmsv2 *parms );
 
 G_END_DECLS
 
-#endif /* __FILE_MANAGER_ACTIONS_API_NA_IIMPORTER_H__ */
+#endif /* __FILE_MANAGER_ACTIONS_API_IIMPORTER_H__ */
diff --git a/src/core/Makefile.am b/src/core/Makefile.am
index bf5387d..97a4fb1 100644
--- a/src/core/Makefile.am
+++ b/src/core/Makefile.am
@@ -82,7 +82,7 @@ libna_core_la_SOURCES = \
        fma-iexporter.c                                                                         \
        fma-ifactory-object.c                                                           \
        fma-ifactory-provider.c                                                         \
-       na-iimporter.c                                                                          \
+       fma-iimporter.c                                                                         \
        na-iio-provider.c                                                                       \
        na-import-mode.c                                                                        \
        na-import-mode.h                                                                        \
diff --git a/src/core/na-importer-ask.c b/src/core/na-importer-ask.c
index 1ade8cd..2cd68f3 100644
--- a/src/core/na-importer-ask.c
+++ b/src/core/na-importer-ask.c
@@ -33,7 +33,7 @@
 
 #include <glib/gi18n.h>
 
-#include <api/na-iimporter.h>
+#include <api/fma-iimporter.h>
 #include <api/na-object-api.h>
 
 #include "na-gtk-utils.h"
@@ -302,7 +302,7 @@ import_ask_new( GtkWindow *parent )
  * na_importer_ask_user:
  * @importing: the #NAObjectItem-derived object being currently imported.
  * @existing: the #NAObjectItem-derived already existing object with the same ID.
- * @parms: a #NAIImporterUriParms structure.
+ * @parms: a #FMAIImporterUriParms structure.
  *
  * Ask the user for what to do when an imported item has the same ID
  * that an already existing one.
diff --git a/src/core/na-pivot.h b/src/core/na-pivot.h
index 3134146..e45d0ef 100644
--- a/src/core/na-pivot.h
+++ b/src/core/na-pivot.h
@@ -138,7 +138,7 @@ NAPivot      *na_pivot_new ( void );
 void          na_pivot_dump( const NAPivot *pivot );
 
 /* Management of the plugins which claim to implement a FileManager-Actions interface.
- * As of 2.30, these may be NAIIOProvider, NAIImporter or FMAIExporter
+ * As of 2.30, these may be NAIIOProvider, FMAIImporter or FMAIExporter
  */
 GList        *na_pivot_get_providers ( const NAPivot *pivot, GType type );
 void          na_pivot_free_providers( GList *providers );
diff --git a/src/io-desktop/nadp-desktop-provider.c b/src/io-desktop/nadp-desktop-provider.c
index 9448ad4..2c6d14b 100644
--- a/src/io-desktop/nadp-desktop-provider.c
+++ b/src/io-desktop/nadp-desktop-provider.c
@@ -67,8 +67,8 @@ static guint  iio_provider_get_version( const NAIIOProvider *provider );
 static void   ifactory_provider_iface_init( FMAIFactoryProviderInterface *iface );
 static guint  ifactory_provider_get_version( const FMAIFactoryProvider *reader );
 
-static void   iimporter_iface_init( NAIImporterInterface *iface );
-static guint  iimporter_get_version( const NAIImporter *importer );
+static void   iimporter_iface_init( FMAIImporterInterface *iface );
+static guint  iimporter_get_version( const FMAIImporter *importer );
 
 static void   iexporter_iface_init( FMAIExporterInterface *iface );
 static guint  iexporter_get_version( const FMAIExporter *exporter );
@@ -133,7 +133,7 @@ nadp_desktop_provider_register_type( GTypeModule *module )
 
        g_type_module_add_interface( module, st_module_type, FMA_TYPE_IFACTORY_PROVIDER, 
&ifactory_provider_iface_info );
 
-       g_type_module_add_interface( module, st_module_type, NA_TYPE_IIMPORTER, &iimporter_iface_info );
+       g_type_module_add_interface( module, st_module_type, FMA_TYPE_IIMPORTER, &iimporter_iface_info );
 
        g_type_module_add_interface( module, st_module_type, FMA_TYPE_IEXPORTER, &iexporter_iface_info );
 }
@@ -282,7 +282,7 @@ ifactory_provider_get_version( const FMAIFactoryProvider *reader )
 }
 
 static void
-iimporter_iface_init( NAIImporterInterface *iface )
+iimporter_iface_init( FMAIImporterInterface *iface )
 {
        static const gchar *thisfn = "nadp_desktop_provider_iimporter_iface_init";
 
@@ -293,7 +293,7 @@ iimporter_iface_init( NAIImporterInterface *iface )
 }
 
 static guint
-iimporter_get_version( const NAIImporter *importer )
+iimporter_get_version( const FMAIImporter *importer )
 {
        return( 2 );
 }
diff --git a/src/io-desktop/nadp-reader.h b/src/io-desktop/nadp-reader.h
index a4ccb18..3edc8cd 100644
--- a/src/io-desktop/nadp-reader.h
+++ b/src/io-desktop/nadp-reader.h
@@ -31,14 +31,14 @@
 #define __NADP_READER_H__
 
 #include <api/na-iio-provider.h>
-#include <api/na-iimporter.h>
+#include <api/fma-iimporter.h>
 #include <api/fma-ifactory-provider.h>
 
 G_BEGIN_DECLS
 
 GList       *nadp_iio_provider_read_items            ( const NAIIOProvider *provider, GSList **messages );
 
-guint        nadp_reader_iimporter_import_from_uri   ( const NAIImporter *instance, void *parms_ptr );
+guint        nadp_reader_iimporter_import_from_uri   ( const FMAIImporter *instance, void *parms_ptr );
 
 void         nadp_reader_ifactory_provider_read_start( const FMAIFactoryProvider *reader, void *reader_data, 
const FMAIFactoryObject *serializable, GSList **messages );
 FMADataBoxed *nadp_reader_ifactory_provider_read_data ( const FMAIFactoryProvider *reader, void 
*reader_data, const FMAIFactoryObject *serializable, const FMADataDef *iddef, GSList **messages );
diff --git a/src/io-xml/naxml-provider.c b/src/io-xml/naxml-provider.c
index cb9e5e5..d23d5b2 100644
--- a/src/io-xml/naxml-provider.c
+++ b/src/io-xml/naxml-provider.c
@@ -33,7 +33,7 @@
 
 #include <api/fma-ifactory-provider.h>
 #include <api/fma-iexporter.h>
-#include <api/na-iimporter.h>
+#include <api/fma-iimporter.h>
 
 #include "naxml-provider.h"
 #include "naxml-formats.h"
@@ -60,8 +60,8 @@ static void   instance_init( GTypeInstance *instance, gpointer klass );
 static void   instance_dispose( GObject *object );
 static void   instance_finalize( GObject *object );
 
-static void   iimporter_iface_init( NAIImporterInterface *iface );
-static guint  iimporter_get_version( const NAIImporter *importer );
+static void   iimporter_iface_init( FMAIImporterInterface *iface );
+static guint  iimporter_get_version( const FMAIImporter *importer );
 
 static void   iexporter_iface_init( FMAIExporterInterface *iface );
 static guint  iexporter_get_version( const FMAIExporter *exporter );
@@ -117,7 +117,7 @@ naxml_provider_register_type( GTypeModule *module )
 
        st_module_type = g_type_module_register_type( module, G_TYPE_OBJECT, "NAXMLProvider", &info, 0 );
 
-       g_type_module_add_interface( module, st_module_type, NA_TYPE_IIMPORTER, &iimporter_iface_info );
+       g_type_module_add_interface( module, st_module_type, FMA_TYPE_IIMPORTER, &iimporter_iface_info );
 
        g_type_module_add_interface( module, st_module_type, FMA_TYPE_IEXPORTER, &iexporter_iface_info );
 
@@ -203,7 +203,7 @@ instance_finalize( GObject *object )
 }
 
 static void
-iimporter_iface_init( NAIImporterInterface *iface )
+iimporter_iface_init( FMAIImporterInterface *iface )
 {
        static const gchar *thisfn = "naxml_provider_iimporter_iface_init";
 
@@ -214,7 +214,7 @@ iimporter_iface_init( NAIImporterInterface *iface )
 }
 
 static guint
-iimporter_get_version( const NAIImporter *importer )
+iimporter_get_version( const FMAIImporter *importer )
 {
        return( 2 );
 }
diff --git a/src/io-xml/naxml-reader.h b/src/io-xml/naxml-reader.h
index 88dc67e..2a949c8 100644
--- a/src/io-xml/naxml-reader.h
+++ b/src/io-xml/naxml-reader.h
@@ -45,7 +45,7 @@
  */
 
 #include <api/fma-data-boxed.h>
-#include <api/na-iimporter.h>
+#include <api/fma-iimporter.h>
 #include <api/fma-ifactory-provider.h>
 
 G_BEGIN_DECLS
@@ -77,7 +77,7 @@ typedef struct {
 
 GType        naxml_reader_get_type( void );
 
-guint        naxml_reader_import_from_uri( const NAIImporter *instance, void *parms_ptr );
+guint        naxml_reader_import_from_uri( const FMAIImporter *instance, void *parms_ptr );
 
 void         naxml_reader_read_start( const FMAIFactoryProvider *provider, void *reader_data, const 
FMAIFactoryObject *object, GSList **messages  );
 FMADataBoxed *naxml_reader_read_data ( const FMAIFactoryProvider *provider, void *reader_data, const 
FMAIFactoryObject *object, const FMADataDef *def, GSList **messages );
diff --git a/src/nact/nact-preferences-editor.c b/src/nact/nact-preferences-editor.c
index 2d4b2c8..962671a 100644
--- a/src/nact/nact-preferences-editor.c
+++ b/src/nact/nact-preferences-editor.c
@@ -34,7 +34,7 @@
 #include <glib/gi18n.h>
 #include <libintl.h>
 
-#include <api/na-iimporter.h>
+#include <api/fma-iimporter.h>
 
 #include <core/na-desktop-environment.h>
 #include <core/na-exporter.h>



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/core/na-iimporter.c b/src/core/fma-iimporter.c
similarity index 76%
rename from src/core/na-iimporter.c
rename to src/core/fma-iimporter.c
index 3c6a53e..110600c 100644
--- a/src/core/na-iimporter.c
+++ b/src/core/fma-iimporter.c
@@ -34,33 +34,33 @@
 #include <glib/gi18n.h>
 
 #include <api/fma-core-utils.h>
-#include <api/na-iimporter.h>
+#include <api/fma-iimporter.h>
 #include <api/na-object-api.h>
 
 /* private interface data
  */
-struct _NAIImporterInterfacePrivate {
+struct _FMAIImporterInterfacePrivate {
        void *empty;                                            /* so that gcc -pedantic is happy */
 };
 
 static guint st_initializations = 0;   /* interface initialization count */
 
 static GType register_type( void );
-static void  interface_base_init( NAIImporterInterface *klass );
-static void  interface_base_finalize( NAIImporterInterface *klass );
-static guint iimporter_get_version( const NAIImporter *instance );
+static void  interface_base_init( FMAIImporterInterface *klass );
+static void  interface_base_finalize( FMAIImporterInterface *klass );
+static guint iimporter_get_version( const FMAIImporter *instance );
 
 #ifdef NA_ENABLE_DEPRECATED
-static void  renumber_label_item( NAIImporterManageImportModeParms *parms );
+static void  renumber_label_item( FMAIImporterManageImportModeParms *parms );
 #endif
 
 /**
- * na_iimporter_get_type:
+ * fma_iimporter_get_type:
  *
  * Returns: the #GType type of this interface.
  */
 GType
-na_iimporter_get_type( void )
+fma_iimporter_get_type( void )
 {
        static GType type = 0;
 
@@ -72,18 +72,18 @@ na_iimporter_get_type( void )
 }
 
 /*
- * na_iimporter_register_type:
+ * fma_iimporter_register_type:
  *
  * Registers this interface.
  */
 static GType
 register_type( void )
 {
-       static const gchar *thisfn = "na_iimporter_register_type";
+       static const gchar *thisfn = "fma_iimporter_register_type";
        GType type;
 
        static const GTypeInfo info = {
-               sizeof( NAIImporterInterface ),
+               sizeof( FMAIImporterInterface ),
                ( GBaseInitFunc ) interface_base_init,
                ( GBaseFinalizeFunc ) interface_base_finalize,
                NULL,
@@ -96,7 +96,7 @@ register_type( void )
 
        g_debug( "%s", thisfn );
 
-       type = g_type_register_static( G_TYPE_INTERFACE, "NAIImporter", &info, 0 );
+       type = g_type_register_static( G_TYPE_INTERFACE, "FMAIImporter", &info, 0 );
 
        g_type_interface_add_prerequisite( type, G_TYPE_OBJECT );
 
@@ -104,15 +104,15 @@ register_type( void )
 }
 
 static void
-interface_base_init( NAIImporterInterface *klass )
+interface_base_init( FMAIImporterInterface *klass )
 {
-       static const gchar *thisfn = "na_iimporter_interface_base_init";
+       static const gchar *thisfn = "fma_iimporter_interface_base_init";
 
        if( !st_initializations ){
 
                g_debug( "%s: klass%p (%s)", thisfn, ( void * ) klass, G_OBJECT_CLASS_NAME( klass ));
 
-               klass->private = g_new0( NAIImporterInterfacePrivate, 1 );
+               klass->private = g_new0( FMAIImporterInterfacePrivate, 1 );
 
                klass->get_version = iimporter_get_version;
                klass->import_from_uri = NULL;
@@ -122,9 +122,9 @@ interface_base_init( NAIImporterInterface *klass )
 }
 
 static void
-interface_base_finalize( NAIImporterInterface *klass )
+interface_base_finalize( FMAIImporterInterface *klass )
 {
-       static const gchar *thisfn = "na_iimporter_interface_base_finalize";
+       static const gchar *thisfn = "fma_iimporter_interface_base_finalize";
 
        st_initializations -= 1;
 
@@ -137,21 +137,21 @@ interface_base_finalize( NAIImporterInterface *klass )
 }
 
 static guint
-iimporter_get_version( const NAIImporter *instance )
+iimporter_get_version( const FMAIImporter *instance )
 {
        return( 1 );
 }
 
 /**
  * na_iimporter_import_from_uri:
  * @importer: this #NAIImporter instance.
  * @parms: a #NAIImporterImportFromUriParmsv2 structure.
  *
  * Tries to import a #NAObjectItem from the URI specified in @parms, returning
  * the result in <structfield>@parms->imported</structfield>.
  *
  * Note that, starting with &prodname; 3.2, the @parms argument is no more a
- * #NAIImporterImportFromUriParms pointer, but a #NAIImporterImportFromUriParmsv2
+ * #FMAIImporterImportFromUriParms pointer, but a #FMAIImporterImportFromUriParmsv2
  * one.
  *
  * Returns: the return code of the operation.
@@ -160,12 +160,12 @@ iimporter_get_version( const NAIImporter *instance )
  */
 
 guint
-na_iimporter_import_from_uri( const NAIImporter *importer, NAIImporterImportFromUriParmsv2 *parms )
+fma_iimporter_import_from_uri( const FMAIImporter *importer, FMAIImporterImportFromUriParmsv2 *parms )
 {
-       static const gchar *thisfn = "na_iimporter_import_from_uri";
+       static const gchar *thisfn = "fma_iimporter_import_from_uri";
        guint code;
 
-       g_return_val_if_fail( NA_IS_IIMPORTER( importer ), IMPORTER_CODE_PROGRAM_ERROR );
+       g_return_val_if_fail( FMA_IS_IIMPORTER( importer ), IMPORTER_CODE_PROGRAM_ERROR );
        g_return_val_if_fail( parms && parms->version == 2, IMPORTER_CODE_PROGRAM_ERROR );
 
        code = IMPORTER_CODE_NOT_WILLING_TO;
@@ -173,8 +173,8 @@ na_iimporter_import_from_uri( const NAIImporter *importer, NAIImporterImportFrom
        g_debug( "%s: importer=%p (%s), parms=%p", thisfn,
                        ( void * ) importer, G_OBJECT_TYPE_NAME( importer), ( void * ) parms );
 
-       if( NA_IIMPORTER_GET_INTERFACE( importer )->import_from_uri ){
-               code = NA_IIMPORTER_GET_INTERFACE( importer )->import_from_uri( importer, parms );
+       if( FMA_IIMPORTER_GET_INTERFACE( importer )->import_from_uri ){
+               code = FMA_IIMPORTER_GET_INTERFACE( importer )->import_from_uri( importer, parms );
        }
 
        return( code );
@@ -182,10 +182,10 @@ na_iimporter_import_from_uri( const NAIImporter *importer, NAIImporterImportFrom
 
 #ifdef NA_ENABLE_DEPRECATED
 /**
- * na_iimporter_manage_import_mode:
- * @parms: a #NAIImporterManageImportModeParms struct.
+ * fma_iimporter_manage_import_mode:
+ * @parms: a #FMAIImporterManageImportModeParms struct.
  *
  * Returns: the #NAIImporterImportStatus status of the operation:
  *
  * <itemizedlist>
  *   <listitem>
@@ -215,9 +215,9 @@ na_iimporter_import_from_uri( const NAIImporter *importer, NAIImporterImportFrom
  * Deprecated: 3.2
  */
 guint
-na_iimporter_manage_import_mode( NAIImporterManageImportModeParms *parms )
+fma_iimporter_manage_import_mode( FMAIImporterManageImportModeParms *parms )
 {
-       static const gchar *thisfn = "na_iimporter_manage_import_mode";
+       static const gchar *thisfn = "fma_iimporter_manage_import_mode";
        guint code;
        NAObjectItem *exists;
        guint mode;
@@ -299,7 +299,7 @@ na_iimporter_manage_import_mode( NAIImporterManageImportModeParms *parms )
  * renumber the item, and set a new label
  */
 static void
-renumber_label_item( NAIImporterManageImportModeParms *parms )
+renumber_label_item( FMAIImporterManageImportModeParms *parms )
 {
        gchar *label, *tmp;
 
@@ -137,21 +137,21 @@ interface_base_finalize( NAIImporterInterface *klass )
 
 /**
- * na_iimporter_import_from_uri:
- * @importer: this #NAIImporter instance.
- * @parms: a #NAIImporterImportFromUriParmsv2 structure.
+ * fma_iimporter_import_from_uri:
+ * @importer: this #FMAIImporter instance.
+ * @parms: a #FMAIImporterImportFromUriParmsv2 structure.
  *
  * Tries to import a #NAObjectItem from the URI specified in @parms, returning
@@ -182,10 +182,10 @@ na_iimporter_import_from_uri( const NAIImporter *importer, NAIImporterImportFrom
  *
- * Returns: the #NAIImporterImportStatus status of the operation:
+ * Returns: the #FMAIImporterImportStatus status of the operation:
  *
  * <itemizedlist>
diff --git a/src/core/na-importer.c b/src/core/na-importer.c
index 536be96..9db7ea7 100644
--- a/src/core/na-importer.c
+++ b/src/core/na-importer.c
@@ -35,7 +35,7 @@
 #include <string.h>
 
 #include <api/fma-core-utils.h>
-#include <api/na-iimporter.h>
+#include <api/fma-iimporter.h>
 #include <api/na-object-api.h>
 
 #include "na-import-mode.h"
@@ -107,7 +107,7 @@ static NAIOption        *get_mode_from_struct( const NAImportModeStr *str );
  *
  * Imports a list of URIs.
  *
  * For each URI to import, we search through the available #NAIImporter
  * providers until the first which returns with something different from
  * "not_willing_to" code.
  *
@@ -116,7 +116,7 @@ static NAIOption        *get_mode_from_struct( const NAImportModeStr *str );
  * Each import operation will have its corresponding newly allocated
  * #NAImporterResult structure which will contain:
  * - the imported URI
  * - the #NAIImporter provider if one has been found, or %NULL
  * - a #NAObjectItem item if import was successful, or %NULL
  * - a list of error messages, or %NULL.
  *
@@ -145,7 +145,7 @@ na_importer_import_from_uris( const NAPivot *pivot, NAImporterParms *parms )
 
        /* first phase: just try to import the uris into memory
         */
-       modules = na_pivot_get_providers( pivot, NA_TYPE_IIMPORTER );
+       modules = na_pivot_get_providers( pivot, FMA_TYPE_IIMPORTER );
 
        for( uri = parms->uris ; uri ; uri = uri->next ){
                import_result = import_from_uri( pivot, modules, ( const gchar * ) uri->data );
@@ -177,7 +177,7 @@ na_importer_import_from_uris( const NAPivot *pivot, NAImporterParms *parms )
 
                if( import_result->imported ){
                        g_return_val_if_fail( NA_IS_OBJECT_ITEM( import_result->imported ), NULL );
-                       g_return_val_if_fail( NA_IS_IIMPORTER( import_result->importer ), NULL );
+                       g_return_val_if_fail( FMA_IS_IIMPORTER( import_result->importer ), NULL );
 
                        ask_parms.uri = import_result->uri;
                        manage_import_mode( parms, results, &ask_parms, import_result );
@@ -203,7 +203,7 @@ na_importer_free_result( NAImporterResult *result )
 }
 
 /*
  * Each NAIImporter interface may return some messages, specially if it
  * recognized but is not able to import the provided URI. But as long
  * we do not have yet asked to all available interfaces, we are not sure
  * of whether this URI is eventually importable or not.
@@ -216,18 +216,18 @@ static NAImporterResult *
 import_from_uri( const NAPivot *pivot, GList *modules, const gchar *uri )
 {
        NAImporterResult *result;
-       NAIImporterImportFromUriParmsv2 provider_parms;
+       FMAIImporterImportFromUriParmsv2 provider_parms;
        GList *im;
        guint code;
        GSList *all_messages;
-       NAIImporter *provider;
+       FMAIImporter *provider;
 
        result = NULL;
        all_messages = NULL;
        provider = NULL;
        code = IMPORTER_CODE_NOT_WILLING_TO;
 
-       memset( &provider_parms, '\0', sizeof( NAIImporterImportFromUriParmsv2 ));
+       memset( &provider_parms, '\0', sizeof( FMAIImporterImportFromUriParmsv2 ));
        provider_parms.version = 2;
        provider_parms.content = 1;
        provider_parms.uri = uri;
@@ -236,7 +236,7 @@ import_from_uri( const NAPivot *pivot, GList *modules, const gchar *uri )
                        im && ( code == IMPORTER_CODE_NOT_WILLING_TO || code == IMPORTER_CODE_NOT_LOADABLE ) ;
                        im = im->next ){
 
-               code = na_iimporter_import_from_uri( NA_IIMPORTER( im->data ), &provider_parms );
+               code = fma_iimporter_import_from_uri( FMA_IIMPORTER( im->data ), &provider_parms );
 
                if( code == IMPORTER_CODE_NOT_WILLING_TO ){
                        all_messages = g_slist_concat( all_messages, provider_parms.messages );
@@ -252,7 +252,7 @@ import_from_uri( const NAPivot *pivot, GList *modules, const gchar *uri )
                } else {
                        fma_core_utils_slist_free( all_messages );
                        all_messages = provider_parms.messages;
-                       provider = NA_IIMPORTER( im->data );
+                       provider = FMA_IIMPORTER( im->data );
                }
        }
 
@@ -107,7 +107,7 @@ static NAIOption        *get_mode_from_struct( const NAImportModeStr *str );
  * Imports a list of URIs.
  *
- * For each URI to import, we search through the available #NAIImporter
+ * For each URI to import, we search through the available #FMAIImporter
  * providers until the first which returns with something different from
  * "not_willing_to" code.
@@ -116,7 +116,7 @@ static NAIOption        *get_mode_from_struct( const NAImportModeStr *str );
  * #NAImporterResult structure which will contain:
  * - the imported URI
- * - the #NAIImporter provider if one has been found, or %NULL
+ * - the #FMAIImporter provider if one has been found, or %NULL
  * - a #NAObjectItem item if import was successful, or %NULL
  * - a list of error messages, or %NULL.
@@ -203,7 +203,7 @@ na_importer_free_result( NAImporterResult *result )
 
 /*
- * Each NAIImporter interface may return some messages, specially if it
+ * Each FMAIImporter interface may return some messages, specially if it
  * recognized but is not able to import the provided URI. But as long
  * we do not have yet asked to all available interfaces, we are not sure
diff --git a/src/core/na-importer.h b/src/core/na-importer.h
index 2f149e0..33cd658 100644
--- a/src/core/na-importer.h
+++ b/src/core/na-importer.h
@@ -30,12 +30,12 @@
 #ifndef __CORE_NA_IMPORTER_H__
 #define __CORE_NA_IMPORTER_H__
 
 /* @title: NAIImporter
  * @short_description: The #NAIImporter Internal Functions
  * @include: core/na-importer.h
  *
  * Internal FileManager-Actions code should never directly call a
  * #NAIImporter interface method, but rather should call the
  * corresponding na_importer_xxx() functions.
  *
  * Importing items is a three-phase operation:
@@ -57,7 +57,7 @@
 
 #include <gtk/gtk.h>
 
-#include <api/na-iimporter.h>
+#include <api/fma-iimporter.h>
 #include <api/na-object-item.h>
 
 #include "na-ioption.h"
@@ -77,8 +77,8 @@ G_BEGIN_DECLS
  *
  * Since: 3.2
  *
  * This same enum used to be defined as NAIImporterImportMode in api/na-iimporter.h
  * header. The enum has been deprecated there in N-A 3.2 when the NAIImporter v2
  * interface was defined. It has so been moved here with the NAImporterImportMode
  * name.
  */
@@ -131,7 +131,7 @@ typedef struct {
         */
        gchar        *uri;                                      /* the imported uri */
        NAObjectItem *imported;                         /* the imported NAObjectItem-derived object, or %NULL 
*/
-       NAIImporter  *importer;                         /* the importer module, or %NULL */
+       FMAIImporter  *importer;                                /* the importer module, or %NULL */
 
        /* phase 2: check for pre-existence
         */
@@ -30,12 +30,12 @@
 #define __CORE_NA_IMPORTER_H__
 
-/* @title: NAIImporter
- * @short_description: The #NAIImporter Internal Functions
+/* @title: FMAIImporter
+ * @short_description: The #FMAIImporter Internal Functions
  * @include: core/na-importer.h
  *
@@ -30,12 +30,12 @@
  *
  * Internal FileManager-Actions code should never directly call a
- * #NAIImporter interface method, but rather should call the
+ * #FMAIImporter interface method, but rather should call the
  * corresponding na_importer_xxx() functions.
  *
@@ -77,8 +77,8 @@ G_BEGIN_DECLS
  * Since: 3.2
  *
- * This same enum used to be defined as NAIImporterImportMode in api/na-iimporter.h
- * header. The enum has been deprecated there in N-A 3.2 when the NAIImporter v2
+ * This same enum used to be defined as FMAIImporterImportMode in api/fma-iimporter.h
+ * header. The enum has been deprecated there in N-A 3.2 when the FMAIImporter v2
  * interface was defined. It has so been moved here with the NAImporterImportMode
  * name.
diff --git a/src/io-desktop/nadp-reader.c b/src/io-desktop/nadp-reader.c
index 835de12..aef76b0 100644
--- a/src/io-desktop/nadp-reader.c
+++ b/src/io-desktop/nadp-reader.c
@@ -343,8 +343,8 @@ free_desktop_paths( GList *paths )
 
 /**
  * nadp_reader_iimporter_import_from_uri:
  * @instance: the #NAIImporter provider.
  * @parms: a #NAIImporterUriParms structure.
  *
  * Imports an item.
  *
@@ -357,23 +357,23 @@ free_desktop_paths( GList *paths )
  * So we have to load the file into memory, and then try to load the key
  * file from the memory data.
  *
  * Starting with N-A 3.2, we only honor the version 2 of #NAIImporter interface,
  * thus no more checking here against possible duplicate identifiers.
  */
 guint
-nadp_reader_iimporter_import_from_uri( const NAIImporter *instance, void *parms_ptr )
+nadp_reader_iimporter_import_from_uri( const FMAIImporter *instance, void *parms_ptr )
 {
        static const gchar *thisfn = "nadp_reader_iimporter_import_from_uri";
        guint code;
-       NAIImporterImportFromUriParmsv2 *parms;
+       FMAIImporterImportFromUriParmsv2 *parms;
        NadpDesktopFile *ndf;
 
        g_debug( "%s: instance=%p, parms=%p", thisfn, ( void * ) instance, parms_ptr );
 
-       g_return_val_if_fail( NA_IS_IIMPORTER( instance ), IMPORTER_CODE_PROGRAM_ERROR );
+       g_return_val_if_fail( FMA_IS_IIMPORTER( instance ), IMPORTER_CODE_PROGRAM_ERROR );
        g_return_val_if_fail( NADP_IS_DESKTOP_PROVIDER( instance ), IMPORTER_CODE_PROGRAM_ERROR );
 
-       parms = ( NAIImporterImportFromUriParmsv2 * ) parms_ptr;
+       parms = ( FMAIImporterImportFromUriParmsv2 * ) parms_ptr;
 
        if( !fma_core_utils_file_is_loadable( parms->uri )){
                code = IMPORTER_CODE_NOT_LOADABLE;
@@ -343,8 +343,8 @@ free_desktop_paths( GList *paths )
 /**
  * nadp_reader_iimporter_import_from_uri:
- * @instance: the #NAIImporter provider.
- * @parms: a #NAIImporterUriParms structure.
+ * @instance: the #FMAIImporter provider.
+ * @parms: a #FMAIImporterUriParms structure.
  *
  * Imports an item.
@@ -357,23 +357,23 @@ free_desktop_paths( GList *paths )
  * file from the memory data.
  *
- * Starting with N-A 3.2, we only honor the version 2 of #NAIImporter interface,
+ * Starting with N-A 3.2, we only honor the version 2 of #FMAIImporter interface,
  * thus no more checking here against possible duplicate identifiers.
  */
diff --git a/src/io-xml/naxml-reader.c b/src/io-xml/naxml-reader.c
index 404d021..05a7af4 100644
--- a/src/io-xml/naxml-reader.c
+++ b/src/io-xml/naxml-reader.c
@@ -77,8 +77,8 @@ struct _NAXMLReaderPrivate {
 
        /* data provided by the caller
         */
-       NAIImporter                     *importer;
-       NAIImporterImportFromUriParmsv2 *parms;
+       FMAIImporter                     *importer;
+       FMAIImporterImportFromUriParmsv2 *parms;
 
        /* data dynamically set during the import operation
         */
@@ -305,8 +305,8 @@ reader_new( void )
 
 /**
  * naxml_reader_import_uri:
  * @instance: the #NAIImporter provider.
  * @parms: a #NAIImporterImportFromUriParmsv2 structure.
  *
  * Imports an item.
  *
@@ -316,22 +316,22 @@ reader_new( void )
  *  then we do not return any error message at all, but just the 'unwilling to'
  *  code.
  *
  * Starting with N-A 3.2, we only honor the version 2 of #NAIImporter interface,
  * thus no more checking here against possible duplicate identifiers.
  */
 guint
-naxml_reader_import_from_uri( const NAIImporter *instance, void *parms_ptr )
+naxml_reader_import_from_uri( const FMAIImporter *instance, void *parms_ptr )
 {
        static const gchar *thisfn = "naxml_reader_import_from_uri";
        NAXMLReader *reader;
-       NAIImporterImportFromUriParmsv2* parms;
+       FMAIImporterImportFromUriParmsv2* parms;
        guint code;
 
        g_debug( "%s: instance=%p, parms=%p", thisfn, ( void * ) instance, parms_ptr );
 
-       g_return_val_if_fail( NA_IS_IIMPORTER( instance ), IMPORTER_CODE_PROGRAM_ERROR );
+       g_return_val_if_fail( FMA_IS_IIMPORTER( instance ), IMPORTER_CODE_PROGRAM_ERROR );
 
-       parms = ( NAIImporterImportFromUriParmsv2 * ) parms_ptr;
+       parms = ( FMAIImporterImportFromUriParmsv2 * ) parms_ptr;
        parms->imported = NULL;
 
        if( !fma_core_utils_file_is_loadable( parms->uri )){
@@ -339,7 +339,7 @@ naxml_reader_import_from_uri( const NAIImporter *instance, void *parms_ptr )
        }
 
        reader = reader_new();
-       reader->private->importer = ( NAIImporter * ) instance;
+       reader->private->importer = ( FMAIImporter * ) instance;
        reader->private->parms = parms;
 
        code = reader_parse_xmldoc( reader );
@@ -305,8 +305,8 @@ reader_new( void )
 /**
  * naxml_reader_import_uri:
- * @instance: the #NAIImporter provider.
- * @parms: a #NAIImporterImportFromUriParmsv2 structure.
+ * @instance: the #FMAIImporter provider.
+ * @parms: a #FMAIImporterImportFromUriParmsv2 structure.
  *
  * Imports an item.
@@ -316,22 +316,22 @@ reader_new( void )
  *  code.
  *
- * Starting with N-A 3.2, we only honor the version 2 of #NAIImporter interface,
+ * Starting with N-A 3.2, we only honor the version 2 of #FMAIImporter interface,
  * thus no more checking here against possible duplicate identifiers.
  */